@@ -6,7 +6,7 @@ from jft.pf import f as pf
 # check_final_line
 def f(Pi=None):
   print('Checking final lines...', end='\r')
-  Pi = list_testables() or Pi
+  Pi = Pi or list_testables()
   for pi in Pi:
     _lines = load(pi).split('\n')
     _last_line_index = len(_lines)-1
