@@ -6,7 +6,7 @@ from jft.text_colours.danger import f as danger
 # check_line_lengths
 def f(Pi=None):
   print('Checking line lengths...', end='\r')
-  Pi = list_testables() or Pi
+  Pi = Pi or list_testables()
   for pi in Pi:
     ignore_line_lengths = False
     for line_index, line in enumerate(load(pi).split('\n')):
