@@ -1,7 +1,7 @@
-from jft.string.single_line_function.to_lambda_str import f as to_λ_str
+from jft.string.single_line_function.to_lambda_str import f as to_l_str
 
 def f(x):
-  y = '\n'.join([to_λ_str(λ) for λ in x.split('\n')])
+  y = '\n'.join([to_l_str(_l) for _l in x.split('\n')])
   return len(x) > len(y), y
 
 def t():
